@@ -66,7 +66,8 @@ class CreateHealthMonitor(neutronV20.CreateCommand):
         parser.add_argument(
             '--delay',
             required=True,
-            help=_('The time in seconds between sending probes to members.'))
+            help=_('The time in milliseconds between sending probes to '
+                   'members.'))
         parser.add_argument(
             '--max-retries',
             required=True,
@@ -75,8 +76,8 @@ class CreateHealthMonitor(neutronV20.CreateCommand):
         parser.add_argument(
             '--timeout',
             required=True,
-            help=_('Maximum number of seconds for a monitor to wait for a '
-                   'connection to be established before it times out. The '
+            help=_('Maximum number of milliseconds for a monitor to wait for '
+                   'a connection to be established before it times out. The '
                    'value must be less than the delay value.'))
         parser.add_argument(
             '--type',
@@ -124,7 +125,7 @@ class AssociateHealthMonitor(neutronV20.NeutronCommand):
             help=_('ID of the pool to be associated with the health monitor.'))
         return parser
 
-    def run(self, parsed_args):
+    def take_action(self, parsed_args):
         neutron_client = self.get_client()
         body = {'health_monitor': {'id': parsed_args.health_monitor_id}}
         pool_id = neutronV20.find_resourceid_by_name_or_id(
@@ -144,13 +145,14 @@ class DisassociateHealthMonitor(neutronV20.NeutronCommand):
         parser = super(DisassociateHealthMonitor, self).get_parser(prog_name)
         parser.add_argument(
             'health_monitor_id', metavar='HEALTH_MONITOR_ID',
-            help=_('Health monitor to associate.'))
+            help=_('Health monitor to disassociate.'))
         parser.add_argument(
             'pool_id', metavar='POOL',
-            help=_('ID of the pool to be associated with the health monitor.'))
+            help=_('ID of the pool to be disassociated with the health '
+                   'monitor.'))
         return parser
 
-    def run(self, parsed_args):
+    def take_action(self, parsed_args):
         neutron_client = self.get_client()
         pool_id = neutronV20.find_resourceid_by_name_or_id(
             neutron_client, 'pool', parsed_args.pool_id)
